@@ -48,6 +48,7 @@
 #include <QTime>
 #include <QSet>
 #include <QScrollArea>
+#include <QElapsedTimer>
 #include <QPushButton>
 
 #include <klocalizedstring.h>
@@ -83,7 +84,7 @@ GlossaryView::GlossaryView(QWidget* parent, Catalog* catalog, const QVector<QAct
     setWidget(m_browser);
     m_browser->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     m_browser->setAutoFillBackground(true);
-    m_browser->setBackgroundRole(QPalette::Background);
+    m_browser->setBackgroundRole(QPalette::Window);
 
     m_rxClean.setMinimal(true);
     connect(m_glossary, &Glossary::changed, this, QOverload<>::of(&GlossaryView::slotNewEntryDisplayed), Qt::QueuedConnection);
