@@ -66,6 +66,7 @@
 #include <QLabel>
 #include <QIcon>
 #include <QApplication>
+#include <QElapsedTimer>
 
 
 LokalizeMainWindow::LokalizeMainWindow()
@@ -291,7 +292,7 @@ EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsA
         if (fp.length()) suggestedDirPath = QFileInfo(fp).absolutePath();
     }
 
-    if (!w->fileOpen(filePath, suggestedDirPath, silent)) {
+    if (!w->fileOpen(filePath, suggestedDirPath, m_fileToEditor, silent)) {
         if (sw) {
             m_mdiArea->removeSubWindow(sw);
             sw->deleteLater();
@@ -299,6 +300,8 @@ EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsA
         w->deleteLater();
         return 0;
     }
+    filePath = w->currentFilePath();
+    m_openRecentFileAction->addUrl(QUrl::fromLocalFile(filePath));//(w->currentUrl());
 
     if (!sw)
         sw = m_mdiArea->addSubWindow(w);
@@ -326,13 +329,11 @@ EditorTab* LokalizeMainWindow::fileOpen(QString filePath, int entry, bool setAsA
     if (!mergeFile.isEmpty())
         w->mergeOpen(mergeFile);
 
-    m_openRecentFileAction->addUrl(QUrl::fromLocalFile(filePath));//(w->currentUrl());
     connect(sw, &QMdiSubWindow::destroyed, this, &LokalizeMainWindow::editorClosed);
     connect(w, &EditorTab::aboutToBeClosed, this, &LokalizeMainWindow::resetMultiEditorAdaptor);
     connect(w, QOverload<const QString &, const QString &, const QString &, const bool>::of(&EditorTab::fileOpenRequested), this, QOverload<const QString &, const QString &, const QString &, const bool>::of(&LokalizeMainWindow::fileOpen));
     connect(w, QOverload<const QString &, const QString &>::of(&EditorTab::tmLookupRequested), this, QOverload<const QString &, const QString &>::of(&LokalizeMainWindow::lookupInTranslationMemory));
 
-    filePath = w->currentFilePath();
     QStringRef fnSlashed = filePath.midRef(filePath.lastIndexOf('/'));
     FileToEditor::const_iterator i = m_fileToEditor.constBegin();
     while (i != m_fileToEditor.constEnd()) {
@@ -468,8 +469,8 @@ void LokalizeMainWindow::setupActions()
     //all operations that can be done after initial setup
     //(via QTimer::singleShot) go to initLater()
 
-    // QTime aaa;
-    // aaa.start();
+//     QElapsedTimer aaa;
+//     aaa.start();
 
     setStandardToolBarMenuEnabled(true);
 
@@ -547,6 +548,10 @@ void LokalizeMainWindow::setupActions()
     action->setText(i18nc("@action:inmenu", "Open project..."));
     action->setIcon(QIcon::fromTheme("project-open"));
 
+    action = proj->addAction(QStringLiteral("project_close"), this, SLOT(closeProject()));
+    action->setText(i18nc("@action:inmenu", "Close project"));
+    action->setIcon(QIcon::fromTheme("project-close"));
+
     m_openRecentProjectAction = new KRecentFilesAction(i18nc("@action:inmenu", "Open recent project"), this);
     action = proj->addAction(QStringLiteral("project_open_recent"), m_openRecentProjectAction);
     connect(m_openRecentProjectAction, QOverload<const QUrl &>::of(&KRecentFilesAction::urlSelected), this, QOverload<const QUrl &>::of(&LokalizeMainWindow::openProject));
@@ -585,6 +590,8 @@ bool LokalizeMainWindow::closeProject()
             m_mdiArea->removeSubWindow(subwindow);
             subwindow->deleteLater();
         }
+        else if (subwindow == m_projectSubWindow && m_projectSubWindow)
+            static_cast<ProjectTab*>(m_projectSubWindow->widget())->showWelcomeScreen();
     }
     Project::instance()->load(QString());
     //TODO scripts
@@ -665,16 +672,13 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
     if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
     KConfig* c = stateGroup.isValid() ? stateGroup.config() : &config;
     m_openRecentFileAction->saveEntries(KConfigGroup(c, "RecentFiles" + nameSpecifier));
-
     m_openRecentProjectAction->saveEntries(KConfigGroup(&config, "RecentProjects"));
 }
 
 void LokalizeMainWindow::readProperties(const KConfigGroup& stateGroup)
 {
     KConfig config;
-    const KConfig* c = stateGroup.isValid() ? stateGroup.config() : &config;
-    m_openRecentProjectAction->loadEntries(KConfigGroup(c, "RecentProjects"));
-
+    m_openRecentProjectAction->loadEntries(KConfigGroup(&config, "RecentProjects"));
     QString path = stateGroup.readEntry("Project", QString());
     if (Project::instance()->isLoaded() || path.isEmpty()) {
         //1. we weren't existing yet when the signal was emitted
@@ -687,8 +691,9 @@ void LokalizeMainWindow::readProperties(const KConfigGroup& stateGroup)
 void LokalizeMainWindow::projectLoaded()
 {
     QString projectPath = Project::instance()->path();
-    qCDebug(LOKALIZE_LOG) << projectPath;
-    m_openRecentProjectAction->addUrl(QUrl::fromLocalFile(projectPath));
+    qCDebug(LOKALIZE_LOG) << "Loaded project : " << projectPath;
+    if (!projectPath.isEmpty())
+        m_openRecentProjectAction->addUrl(QUrl::fromLocalFile(projectPath));
 
     KConfig config;
 
